pub fn Scheme()Expand description
Initializes the scheme handler module
This is a placeholder function that can be used for any future initialization logic needed by the scheme handler.
pub fn Scheme()Initializes the scheme handler module
This is a placeholder function that can be used for any future initialization logic needed by the scheme handler.